#!/bin/sh
# SPDX-License-Identifier: MIT
# Copyright (C) 2019 Beckhoff Automation GmbH & Co. KG

set -u

hostname_prefix() {
	kldload -n bbapi
	local _bios_type=$(/usr/local/bin/BapiCmd /ig:0x0 /io:0xA2 /ibuf:0 /olen:4 | tail -1 | awk '{print "0x"$2}' | awk '{printf("%c", $1)}')

	case "${_bios_type}" in
		'B')
			printf "CP-"
			;;
		'C')
			printf "CX-"
			;;
		*)
			printf "PC-"
			;;
	esac
}

# generate a list of TwinCAT hostname for all MAC addresses
# usage: my_possible_hostnames=$(generate_hostname)
generate_hostname_list() {
	local _prefix="$(hostname_prefix)"
	ifconfig | grep ether | sort | awk '{split(toupper($0),m,":"); print "'"${_prefix}"'"m[4]m[5]m[6]}' | tr '\n' ' '
}

# generate a TwinCAT hostname from 'lowest' MAC addresses
# usage: my_hostname=$(generate_hostname)
generate_hostname() {
	local _hostname=$(echo "$(generate_hostname_list)" | cut -w -f1)
	if [ -z "${_hostname}" ]; then
		_hostname="PC-000000"
	fi
	printf "${_hostname}\n"
}
