#!/bin/sh
# SPDX-License-Identifier: MIT
# Copyright (C) 2020 Beckhoff Automation GmbH & Co. KG

shlib_load_options() {
	local _option_list="${1}"
	local _shifts=0
	local _option_var
	local _option
	shift 1

	for _arg in "$@"; do
		local _old_shifts="${_shifts}"
		for _option in ${_option_list}; do
			case "${_arg}" in
				--${_option}=*)
					_option_var="$(printf '%s' "${_option}" | tr '-' '_')"
					eval "${_option_var}=\"${_arg#*--${_option}=}\""
					_shifts=$((_shifts + 1))
					break
					;;
				--${_option})
					_option_var="$(printf '%s' "${_option}" | tr '-' '_')"
					eval "${_option_var}=\"true\""
					_shifts=$((_shifts + 1))
					break
					;;
				--)
					# stop parsing more arguments
					_shifts=$((_shifts + 1))
					return ${_shifts}
					;;
				--*)
					# try next option
					;;
				*)
					# stop parsing at first positional argument
					return ${_shifts}
					;;
			esac
		done
		if ! test "${_shifts}" -gt "${_old_shifts}"; then
			printf "Unknown option '%s'\n" "${_arg}" >&2
			if type usage > /dev/null; then
				usage
			fi
			exit 1
		fi
	done
	return ${_shifts}
}
