#!/bin/sh
# SPDX-License-Identifier: MIT
# Copyright (C) 2019 Beckhoff Automation GmbH & Co. KG
# Author: Julian Heuking <j.heuking@beckhoff.com>
#
# Collection of very basic helper functions

set -u

# return number of elements seperated by '\n'
# usage: list_length <list>
# f.e.:  length=$(list_length "${list}")
list_length() {
	if [ "${#1}" -eq 0 ]; then
		printf "0\n"
	else
		printf '%s\n' "${1}" | wc -l | tr -d '[:space:]'
	fi
}

# invert bool value (0/1)
# usage: not <value>
# f.e.:  x=$(not 0)
not() {
	[ -z "${1}" ] && return 2
	[ ${1} -ne 0 ]
	printf "$?\n"
}

# exit with error message
# usage: throw <message> [exit code]
# f.e.:  throw "your message"
#        throw "your message" 2
throw() {
	if type logmsg > /dev/null; then
		logmsg "${1}"
	else
		printf "${1}" 1>&2
	fi
	exit ${2-1}
}

# get value of variable specified by name
# return "unset value" when variable is undefined
# unset-value will default to an empty string
# usage: getvar <variable name> [ <unset value> ]
# f.e.   my_var=$(getvar "_remote_var" "unset")
getvar() {
	eval "printf '%s' \"\${${1}-${2-}}\""
}

# check if the arguments contain a specific switch and
# return 0 and the value of the next parameter in that case
# f.e. get value "bla" from --switch:
# 	your_script.sh --switch bla
# with this:
# 	if value="$(get_opt "--switch" "$@")"; then
#		echo "found value for --switch, it's: ${value}"
#	fi
get_opt() {
	local _opt_name="${1}"
	shift
	while [ $# -gt 0 ]; do
		if [ "${1}" = "${_opt_name}" ]; then
			printf "%s${2+\n}" "${2-}"
			return 0
		fi
		shift
	done
	return 1
}
